# Table of Contents

- [configuring-integration-with-jira-service-management](<./configuring-integration-with-jira-service-management.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Configuring the Integration with Jira Service Management](<./Configuring-the-Integration-with-Jira-Service-Management.md>)
  - [Prerequisites](<./Configuring-the-Integration-with-Jira-Service-Management/Prerequisites.md>)
  - [Configuration Overview](<./Configuring-the-Integration-with-Jira-Service-Management/Configuration-Overview.md>)
  - [Step 1: Add the Integration](<./Configuring-the-Integration-with-Jira-Service-Management/Step-1-Add-the-Integration.md>)
  - [Step 2: Configure Credentials](<./Configuring-the-Integration-with-Jira-Service-Management/Step-2-Configure-Credentials.md>)
  - [Step 3: Configure Mappings](<./Configuring-the-Integration-with-Jira-Service-Management/Step-3-Configure-Mappings.md>)
  - [Managing the Integration](<./Configuring-the-Integration-with-Jira-Service-Management/Managing-the-Integration.md>)
  - [Troubleshooting](<./Configuring-the-Integration-with-Jira-Service-Management/Troubleshooting.md>)
  - [Was this page helpful?](<./Configuring-the-Integration-with-Jira-Service-Management/Was-this-page-helpful.md>)
